@@ -1,11 +1,12 @@
 #ifndef __DEFINES_H
 # define __DEFINES_H
+/*!
+*  \file defines.h
+*  \brief Program name, release number and modification symbols.
+*/
 /*
-*  defines.h:  Program name, release number and modification symbols.
-*
-*
-*  Copyright (c) 1994, 95, 96, 1997, 2000 Thomas Esken
-*  Copyright (c) 2010 Free Software Foundation, Inc.
+*  Copyright (c) 1994, 95, 96, 1997, 2000, 2011 Thomas Esken
+*  Copyright (c) 2010, 2011, 2013 Free Software Foundation, Inc.
 *
 *  This software doesn't claim completeness, correctness or usability.
 *  On principle I will not be liable for ANY damages or losses (implicit
@@ -24,24 +25,6 @@
 */
 
 
-
-/*
-*  $Id: defines.h 3.01 2000/06/14 03:00:01 tom Exp $
-*/
-
-
-
-/*
-*  Define the program name and version.
-*/
-/* Actual program name. */
-# define PRGR_NAME   "gcal"
-
-/* Actual version number. */
-# define VERSION_NO  "3.01"
-
-
-
 /*
 *
 *  BEGIN: General program modification symbols,
@@ -58,11 +41,7 @@
 *      - Delete the symbol USE_EASC or write `USE_EASC 0' for using the
 *          ISO-ASCII/EBCDIC character set...
 *
-*  b)  - Define `USE_DE 1' for using German messages and calendar style.
-*      - Delete the symbol USE_DE or write `USE_DE 0' for using
-*          English messages and calendar style...
-*
-*  c)  - Define `USE_HLS 1' to run this program using control sequences
+*  b)  - Define `USE_HLS 1' to run this program using control sequences
 *          for highlighting the current day/holidays/text (MS/PC-DOS will
 *          use the [n]ansi.sys driver for emitting ANSI Escape highlighting
 *          sequences; OS2/Linux/UN*X-like systems will use `termcap' for
@@ -71,13 +50,13 @@
 *      - Delete the symbol USE_HLS or write `USE_HLS 0' to run this program
 *          without highlighting...
 *
-*  d)  - Define `USE_PAGER 1' for using an external pager (availabe only
+*  c)  - Define `USE_PAGER 1' for using an external pager (availabe only
 *          on UN*X-like systems) or for using the simple, internal pager
 *          (if external pager fails).
 *      - Delete the symbol USE_PAGER or write `USE_PAGER 0' if you don't
 *          like this feature...
 *
-*  e)  - Define `USE_RC 1' for using the special month dates functions
+*  d)  - Define `USE_RC 1' for using the special month dates functions
 *          (print daily/weekly/monthly/yearly/eternal/special fixed dates
 *          texts which are stated in the resource file(s)).
 *      - Delete the symbol USE_RC or write `USE_RC 0' if you don't
@@ -87,7 +66,6 @@
 
 # if 0
 #  define USE_EASC   0
-#  define USE_DE     0
 #  define USE_HLS    1
 #  define USE_PAGER  1
 #  define USE_RC     1
